Support for experimental science over BayesDB
=============================================

Pending better documentation, the `design document`_
that led to this package is checked in to the bdbcontrib source
repository.

.. _design document: https://github.com/probcomp/bdbcontrib/blob/master/examples/on-stability-testing.md

 .. toctree::
    :maxdepth: 2

    probe
    visualization
